/*
 * XWaveN -- a simple audio file editor
 * Written by Andrew Church <achurch@achurch.org>
 *
 * src/canvas.h: Header for wave file canvas window management.
 */

#ifndef CANVAS_H
#define CANVAS_H

/*************************************************************************/

/**
 * canvas_create:  Create a new canvas window for the given wave file.
 *
 * [Parameters]
 *     wave: Wave file for which to create a canvas window
 * [Return value]
 *     New canvas window, or NULL on error
 */
extern CanvasWindow *canvas_create(WaveFile *wave);

/**
 * canvas_destroy:  Destroy a canvas window and all associated resources.
 * Does nothing if canvas == NULL.
 *
 * [Parameters]
 *     canvas: Canvas window to destroy
 * [Return value]
 *     None
 */
extern void canvas_destroy(CanvasWindow *canvas);

/**
 * canvas_width:  Return the width of a canvas window.
 *
 * [Parameters]
 *     canvas: Canvas window for which to return width
 * [Return value]
 *     Window width, in pixels
 */
extern unsigned int canvas_width(CanvasWindow *canvas);

/**
 * canvas_refresh:  Refresh the contents of the canvas window, optionally
 * updating the display position.
 *
 * [Parameters]
 *         canvas: Canvas window to refresh
 *     reposition: Nonzero to reposition the wave data display position,
 *                    zero to keep the current display position
 * [Return value]
 *     None
 */
extern void canvas_refresh(CanvasWindow *canvas, int reposition);

/*************************************************************************/

#endif  // CANVAS_H

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
