/*
 * XWaveN -- a simple audio file editor
 * Written by Andrew Church <achurch@achurch.org>
 *
 * src/main.c: Program initialization and main loop.
 */

#include "common.h"
#include "manager.h"
#include "ui.h"
#include "wave.h"

#include <getopt.h>

/*************************************************************************/
/************************** Program entry point **************************/
/*************************************************************************/

/**
 * main:  Program entry point.  Performs initialization, then runs the main
 * loop until the user exits the program.
 *
 * [Parameters]
 *     argc: Command line argument count
 *     argv: Command line argument array
 * [Return value]
 *     Program exit code (zero on normal exit, nonzero on error)
 */
int main(int argc, char **argv)
{
    /* Initialize GTK+ and the user interface. */
    gtk_init(&argc, &argv);
    if (!ui_init()) {
        return 1;
    }

    /* Check for basic command-line options. */
    static const struct option long_options[] = {
        {"help", 0, 0, 'h'},
        {NULL, 0, 0, 0}
    };
    int c;
    while ((c = getopt_long(argc, argv, "h", long_options, NULL)) != -1) {
        switch (c) {
          case 'h':
          default:
            printf("Usage: %s [file...]\n", argv[0]);
            exit(0);
        }
    }

    /* If we have any other command line parameters, assume they're files
     * to load, and load them. */
    int i;
    for (i = 1; i < argc; i++) {
        WaveFile *wave = wave_load(argv[i]);
        if (wave) {
            manager_add_wave(wave);
            manager_set_active_wave(wave);
        } else {
            ui_show_error("Failed to open \"%s\".", argv[i]);
        }
    }

    /* Run the GTK+ main loop. */
    gtk_main();

    return 0;
}

/*************************************************************************/
/*************************************************************************/

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
