/*
 * XWaveN -- a simple audio file editor
 * Written by Andrew Church <achurch@achurch.org>
 *
 * src/manager.h: Header for wave file manager.
 */

#ifndef MANAGER_H
#define MANAGER_H

/*************************************************************************/

/**
 * manager_add_wave:  Add a wave file to the list of loaded files.
 *
 * [Parameters]
 *     wave: Wave file to add
 * [Return value]
 *     None
 */
extern void manager_add_wave(WaveFile *wave);

/**
 * manager_delete_wave:  Delete a wave file to the list of loaded files.
 *
 * [Parameters]
 *     wave: Wave file to delete
 * [Return value]
 *     None
 */
extern void manager_delete_wave(WaveFile *wave);

/**
 * manager_first_wave:  Return the first wave file in the list of loaded
 * files.
 *
 * [Parameters]
 *     None
 * [Return value]
 *     First loaded wave file
 */
extern WaveFile *manager_first_wave(void);

/**
 * manager_next_wave:  Return the next wave file in the list of loaded
 * files after the last call to manager_first_wave() or manager_next_wave().
 * If a wave file is added to the list, or any wave file but the last
 * returned from manager_first_wave() or manager_next_wave() is deleted
 * from the list, the behavior of this function is undefined.
 *
 * [Parameters]
 *     None
 * [Return value]
 *     Next loaded wave file
 */
extern WaveFile *manager_next_wave(void);

/**
 * manager_set_active_wave:  Set the currently active wave file.
 *
 * [Parameters]
 *     wave: Wave file to set as active
 * [Return value]
 *     None
 */
extern void manager_set_active_wave(WaveFile *wave);

/**
 * manager_get_active_wave:  Return the currently active wave file.
 *
 * [Parameters]
 *     None
 * [Return value]
 *     Currently active wave file, or NULL if none
 */
extern WaveFile *manager_get_active_wave(void);

/*************************************************************************/

#endif  // MANAGER_H

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
