/*
 * XWaveN -- a simple audio file editor
 * Written by Andrew Church <achurch@achurch.org>
 *
 * src/ui.h: User interface header.
 */

#ifndef UI_H
#define UI_H

#include <gtk/gtk.h>

/*************************************************************************/

/* Colors for drawing each channel's waveform */
extern const GdkColor channel_colors[];

/**
 * ui_init:  Set up the GTK+ user interface.
 *
 * [Parameters]
 *     None
 * [Return value]
 *     Nonzero on success, zero on failure
 */
extern int ui_init(void);

/**
 * ui_get_widget:  Return a pointer to the named widget in the user
 * interface.  A shortcut for "glade_xml_get_widget(ui,name)".
 *
 * [Parameters]
 *     name: Widget name
 * [Return value]
 *     Pointer to widget, or NULL if not found
 */
extern GtkWidget *ui_get_widget(const char *name);

/**
 * ui_update:  Update the UI after a change in state.
 *
 * [Parameters]
 *     None
 * [Return value]
 *     None
 */
extern void ui_update(void);

/**
 * ui_show_error:  Display an error dialog and wait for the user to
 * dismiss it.
 *
 * [Parameters]
 *     format: Error message format string (printf()-style)
 *        ...: Format arguments
 * [Return value]
 *     None
 */
extern void ui_show_error(const char *format, ...) FORMAT(1,2);

/**
 * ui_close_wave:  Close the given wave file, first prompting the user to
 * save changes if necessary.
 *
 * [Parameters]
 *     wave: Wave file to close
 * [Return value]
 *     Nonzero if the wave file was closed, zero otherwise (e.g., if the
 *     user cancelled the confirmation dialog)
 */
extern int ui_close_wave(WaveFile *wave);

/**
 * ui_in_dialog:  Return whether a dialog window is currently displayed.
 *
 * [Parameters]
 *     None
 * [Return value]
 *     True (nonzero) if a dialog is currently displayed, else false (zero)
 */
extern int ui_in_dialog(void);

/**
 * ui_in_playback:  Return whether a wave file is currently playing.
 *
 * [Parameters]
 *     None
 * [Return value]
 *     True (nonzero) if a wave file is currently playing, else false (zero)
 */
extern int ui_in_playback(void);

/*************************************************************************/

#endif  // UI_H

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
